from distutils.core import setup


setup(
    name='kedaofx',
    version='0.2',
    description='用作数据分析的便捷指令',
    author='lyr',
    author_email='lhx17614480838@163.com',
    py_modules=['kedaofx']
)